==> whacc-0.1.5.tar.gz: whacc-0.1.5/whacc/examples/1_make_h5_example.py <==
from whacc import PoleTracking
import whacc
import glob
import os
import matplotlib.pyplot as plt

mp4_path = "/Users/phil/Dropbox/Autocurator/testing_data/MP4s"
mp4_path = "/Users/phil/Dropbox/HIRES_LAB/GitHub/Phillip_AC/autoCuratorDiverseDataset/AH0000x000000/"
mp4_path = "/Users/phil/Downloads/untitled folder 2/"
mp4_path = "/Users/phil/Dropbox/HIRES_LAB/curation_for_auto_curator/Data/Jon/AH0667/170317/"
mp4_path = '/Users/phil/Downloads/test_pole_tracker/'
# mp4_path = "/Users/phil/Dropbox/HIRES_LAB/GitHub/Phillip_AC/autoCuratorDiverseDataset/delete_after_oct_2021/"
search_term = '*.mp4'
##
folders_with_MP4s = whacc.utils.recursive_dir_finder(mp4_path, search_term)
print(folders_with_MP4s, sep='\n')
# folders_with_MP4s = folders_with_MP4s[:2]

PT = dict()
for i, video_directory in enumerate(folders_with_MP4s):
    template_img_full_name = glob.glob(video_directory + os.path.sep + '*template_img.png')
    if len(template_img_full_name) == 1:  # if the template already exists
        PT[i] = PoleTracking(video_directory=video_directory, template_png_full_name=template_img_full_name[0])
    else:
        PT[i] = PoleTracking(video_directory=video_directory)  # create the class
        PT[i].cut_out_pole_template(crop_size=[61, 61], frame_num=2000,
                                    file_ind=2)  # cut out template image## 270 , 120# 270, 235# 187 , 249# 168 , 276
        PT[i].save_template_img(cust_save_dir=PT[i].video_directory)  # save the template image

for i in PT:
    PT_tmp = PT[i]
    PT_tmp.get_trial_and_file_names(print_them=True, num_to_print=5)
    PT_tmp.save_template_img(cust_save_dir=PT_tmp.video_directory)
    plt.figure()
    plt.title(PT_tmp.video_directory)
    plt.imshow(PT_tmp.template_image)

for i in PT:
    PT[i].use_narrow_search_to_speed_up = False
    output_h5 = PT[i].track_all_and_save()


#
# #
# import h5py
# import copy
# with h5py.File('/Users/phil/Dropbox/Autocurator/testing_data/MP4s/AH0667x170317_JON/AH0667x170317.h5', 'r') as hf:
#     # print(hf.keys())
#     L = copy.deepcopy(hf['locations'][:])
#
#
# #
# import matplotlib.pyplot as plt
# a = L[0]
# plt.plot(a[:, 0], a[:, 1], 'ko')

==> whacc-1.1.73.tar.gz: whacc-1.1.73/whacc/examples/1_make_h5_example.py <==
from whacc import PoleTracking
import whacc
import glob
import os
import matplotlib.pyplot as plt

mp4_path = "/Users/phil/Dropbox/Autocurator/testing_data/MP4s"
mp4_path = "/Users/phil/Dropbox/HIRES_LAB/GitHub/Phillip_AC/autoCuratorDiverseDataset/AH0000x000000/"
mp4_path = "/Users/phil/Downloads/untitled folder 2/"
mp4_path = "/Users/phil/Dropbox/HIRES_LAB/curation_for_auto_curator/Data/Jon/AH0667/170317/"
mp4_path = '/Users/phil/Downloads/test_pole_tracker/'
mp4_path = '/Users/phil/Desktop/trashTMP/'
mp4_path = '/Users/phil/Desktop/trashTMP_old_method'
mp4_path = '/Users/phil/Desktop/trashTMP_new_method'
mp4_path = '/Volumes/GoogleDrive-114825029448473821206/.shortcut-targets-by-id/1pUteMEgx37rAyqujJWxVN9-ywFAqaxhF/WhACC_PROCESSING_FOLDER/Session1_FINISHED_MP4s/Session1/'

# mp4_path = "/Users/phil/Dropbox/HIRES_LAB/GitHub/Phillip_AC/autoCuratorDiverseDataset/delete_after_oct_2021/"
search_term = '*.mp4'
##

folders_with_MP4s = whacc.utils.recursive_dir_finder(mp4_path, search_term)
print(folders_with_MP4s, sep='\n')
# folders_with_MP4s = folders_with_MP4s[:2]

PT = dict()
for i, video_directory in enumerate(folders_with_MP4s):
    template_img_full_name = glob.glob(video_directory + os.path.sep + '*template_img.png')
    if len(template_img_full_name) == 1:  # if the template already exists
        PT[i] = PoleTracking(video_directory=video_directory, template_png_full_name=template_img_full_name[0])
    else:
        PT[i] = PoleTracking(video_directory=video_directory)  # create the class
        PT[i].cut_out_pole_template(crop_size=[61, 61], frame_num=2000,
                                    file_ind=2)  # cut out template image## 270 , 120# 270, 235# 187 , 249# 168 , 276
        PT[i].save_template_img(cust_save_dir=PT[i].video_directory)  # save the template image

for i in PT:
    PT_tmp = PT[i]
    PT_tmp.get_trial_and_file_names(print_them=True, num_to_print=5)
    PT_tmp.save_template_img(cust_save_dir=PT_tmp.video_directory)
    plt.figure()
    plt.title(PT_tmp.video_directory)
    plt.imshow(PT_tmp.template_image)

for i in PT:
    output_h5 = PT[i].track_all_and_save()



import h5py
with h5py.File('/Users/phil/Desktop/pipeline_test/AH0407x160609.h5', 'r') as h:
    tmp1 = h['images'][0]
#

import copy
with h5py.File('/Users/phil/Dropbox/Autocurator/testing_data/MP4s/AH0667x170317_JON/AH0667x170317.h5', 'r') as hf:
    # print(hf.keys())
    L = copy.deepcopy(hf['locations'][:])


#
import matplotlib.pyplot as plt
a = L[0]
plt.plot(a[:, 0], a[:, 1], 'ko')
